@@ -1,11 +1,11 @@
 """Scrypt for Python"""
 
-__version__ = '1.2.0'
+__version__ = '1.2.1'
 
 # First, try loading libscrypt
 _done = False
 try:
-    from pylibscrypt import *
+    from .pylibscrypt import *
 except ImportError:
     pass
 else:
@@ -14,18 +14,27 @@ else:
 # If that didn't work, try the scrypt module
 if not _done:
     try:
-        from pyscrypt import *
+        from .pyscrypt import *
     except ImportError:
         pass
     else:
         _done = True
 
-# Unless we are on pypy, we want to try libsodium as well
+# Next: libsodium
+if not _done:
+    try:
+        from .pylibsodium import *
+    except ImportError:
+        pass
+    else:
+        _done = True
+
+# Unless we are on pypy, we want to try libsodium_salsa as well
 if not _done:
     import platform
     if platform.python_implementation() != 'PyPy':
         try:
-            from pylibsodium_salsa import *
+            from .pylibsodium_salsa import *
         except ImportError:
             pass
         else:
@@ -33,19 +42,8 @@ if not _done:
 
 # If that didn't work either, the inlined Python version
 if not _done:
-    try:
-        from pypyscrypt_inline import *
-    except ImportError:
-        pass
-    else:
-        _done = True
-
-# Finally the non-inlined
-if not _done:
-    from pypyscrypt import *
+    from .pypyscrypt_inline import *
 
 __all__ = ['scrypt', 'scrypt_mcf', 'scrypt_mcf_check']
 
-# Clean up pydoc output
-del __path__
 
