@@ -3,10 +3,10 @@
 
 import time
 
-from common import *
-from pylibscrypt import scrypt
-from pypyscrypt_inline import scrypt as pyscrypt
-from pylibsodium_salsa import scrypt as pcscrypt
+from .common import *
+from .pylibscrypt import scrypt
+from .pypyscrypt_inline import scrypt as pyscrypt
+from .pylibsodium_salsa import scrypt as pcscrypt
 
 
 # Benchmark time in seconds
