@@ -195,7 +195,7 @@ class ScryptTests(unittest.TestCase):
     def test_mcf_padding(self):
         if self.fast:
             self.skipTest('slow testcase')
-        pw = 'pleaseletmein'
+        pw = b'pleaseletmein'
         m1 = (
             b'$s1$020101$U29kaXVtQ2hsb3JpZGU$ux13AWxUOpn+YyycQ8YBgP0F4MrI'
             b'spN029GFRWnLU09IckDPwGnWpZo18vpcdCiyHZvp+EMVRG1TcRGeAW/t9w=='
@@ -338,39 +338,40 @@ def run_pbkdf2_suite(module, fast=False):
 if __name__ == "__main__":
     suite = unittest.TestSuite()
     try:
-        import pylibscrypt
+        from . import pylibscrypt
         suite.addTest(load_scrypt_suite('pylibscryptTests', pylibscrypt, True))
     except ImportError:
         suite.addTest(load_scrypt_suite('pylibscryptTests', None, True))
 
     try:
-        import pyscrypt
+        from . import pyscrypt
         suite.addTest(load_scrypt_suite('pyscryptTests', pyscrypt, True))
     except ImportError:
         suite.addTest(load_scrypt_suite('pyscryptTests', None, True))
 
     try:
-        import pylibsodium
+        from . import pylibsodium
         suite.addTest(load_scrypt_suite('pylibsodiumTests',
                                         pylibsodium, True))
     except ImportError:
+        raise
         suite.addTest(load_scrypt_suite('pylibsodiumTests', None, True))
 
     try:
-        import pylibsodium_salsa
+        from . import pylibsodium_salsa
         suite.addTest(load_scrypt_suite('pylibsodium_salsaTests',
                                         pylibsodium_salsa, True))
     except ImportError:
         suite.addTest(load_scrypt_suite('pylibsodium_salsaTests', None, True))
 
     try:
-        import pypyscrypt_inline as pypyscrypt
+        from . import pypyscrypt_inline as pypyscrypt
         suite.addTest(load_scrypt_suite('pypyscryptTests', pypyscrypt, True))
     except ImportError:
         suite.addTest(load_scrypt_suite('pypyscryptTests', None, True))
 
     try:
-        import pbkdf2
+        from . import pbkdf2
         suite.addTest(load_pbkdf2_suite('pbkdf2', pbkdf2))
     except ImportError:
         suite.addTest(load_pbkdf2_suite('pbkdf2', None))
